TODO
----

-  Configure `rofi <https://github.com/davatorium/rofi>`__
-  Configure `wofi <https://cloudninja.pw/docs/wofi.html>`__: Is it
   dead?
-  Write launcher-menu in python and integrate.
-  Configure others as issues arise
